package cn.com.infosec.asn1.esf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.DERUTF8String;
import java.util.Enumeration;

public class SignerLocation extends ASN1Encodable {
   private DERUTF8String countryName;
   private DERUTF8String localityName;
   private ASN1Sequence postalAddress;

   public SignerLocation(ASN1Sequence seq) {
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         DERTaggedObject var2;
         int var3;
         if ((var3 = (var2 = (DERTaggedObject)seq1.nextElement()).getTagNo()) != 0) {
            if (var3 != 1) {
               if (var3 != 2) {
                  throw new IllegalArgumentException("illegal tag");
               }

               if (var2.isExplicit()) {
                  this.postalAddress = ASN1Sequence.getInstance(var2, true);
               } else {
                  this.postalAddress = ASN1Sequence.getInstance(var2, false);
               }

               ASN1Sequence var5;
               if ((var5 = this.postalAddress) != null && var5.size() > 6) {
                  throw new IllegalArgumentException("postal address must contain less than 6 strings");
               }
            } else {
               this.localityName = DERUTF8String.getInstance(var2, true);
            }
         } else {
            this.countryName = DERUTF8String.getInstance(var2, true);
         }
      }

   }

   public SignerLocation(DERUTF8String countryName, DERUTF8String localityName, ASN1Sequence postalAddress) {
      if (postalAddress != null && postalAddress.size() > 6) {
         throw new IllegalArgumentException("postal address must contain less than 6 strings");
      } else {
         if (countryName != null) {
            this.countryName = DERUTF8String.getInstance(countryName.toASN1Object());
         }

         if (localityName != null) {
            this.localityName = DERUTF8String.getInstance(localityName.toASN1Object());
         }

         if (postalAddress != null) {
            this.postalAddress = ASN1Sequence.getInstance(postalAddress.toASN1Object());
         }

      }
   }

   public static SignerLocation getInstance(Object obj) {
      return obj != null && !(obj instanceof SignerLocation) ? new SignerLocation(ASN1Sequence.getInstance(obj)) : (SignerLocation)obj;
   }

   public DERUTF8String getCountryName() {
      return this.countryName;
   }

   public DERUTF8String getLocalityName() {
      return this.localityName;
   }

   public ASN1Sequence getPostalAddress() {
      return this.postalAddress;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERUTF8String var2;
      DERTaggedObject var3;
      if ((var2 = this.countryName) != null) {
         var3 = new DERTaggedObject.<init>(true, 0, var2);
         var1.add(var3);
      }

      if ((var2 = this.localityName) != null) {
         var3 = new DERTaggedObject.<init>(true, 1, var2);
         var1.add(var3);
      }

      ASN1Sequence var4;
      if ((var4 = this.postalAddress) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(true, 2, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
